jellyfish |release|
===================

Overview
--------

jellyfish is a library of functions for approximate and phonetic matching of strings.

The library provides implementations of the following algorithms:

.. toctree::
   :maxdepth: 3

   phonetic
   stemming
   comparison
   changelog

Implementation
--------------

Each algorithm has C and Python implementations.

On a typical CPython install the C implementation will be used.  The Python versions are available for PyPy and systems where compiling the CPython extension is not possible.


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

